# BioBundles: Simulator-specific implementations of the `process_bigraph.Process` and `process_bigraph.Step` interfaces.

# **TODO: Eventually replace `biosimulators_processes` with this(`bio_bundles`)!!!**